#!/usr/bin/perl -w

# Read test data sets for Cell-line use case and Sanofi RC2 proteomics
# create subset of uniprot for only these entries for rapid loading.

open(TESTDATA, "proteomics_data_list.txt") || die "proteomics_data_list not found";

while(<TESTDATA>) {
    s/[\#].*//;
    if(/^(\S.*\S)$/){
	$pfilename = $1;
	open(PFILE, "$pfilename") || die "Failed to read proteomics file '$pfilename'";
	$pline = <PFILE>;		# skip headers
	while($pline = <PFILE>){
	    @col = split(/\t/,$pline);
	    ++$wantid{$col[1]};
	}
	close PFILE;
    }
}
close TESTDATA;

open(TESTDATA, "rbm_data_list.txt") || die "rbm_data_list not found";

while(<TESTDATA>) {
    s/[\#].*//;
    if(/^(\S.*\S)$/){
	$rfilename = $1;
	open(RFILE, "$rfilename") || die "Failed to read rbm file '$rfilename'";
	$rline = <RFILE>;		# skip headers
	while($rline = <RFILE>){
	    @col = split(/\t/,$rline);
	    $id = $col[2];
	    $id =~ s/ //g;
	    @id = split(/,/,$id);
	    if($id ne "") {
		foreach $id (@id) {
		    print STDERR "Want RBM id $id\n";
		    ++$wantid{$id};
		}
	    }
	}
	close PFILE;
    }
}
close TESTDATA;

$wanted = keys(%wantid);

print STDERR "Reading /data/scratch/git-master/dictionaries/uniprot-dictionary2.tsv\n";
open (DIC, "/data/scratch/git-master/dictionaries/uniprot-dictionary2.tsv") || die "Cannot open dictionary";
$dline = <DIC>;
print $dline;				# save the header line
$saveline = 0;

$line=1;
while($dline = <DIC>){
    $line++;
    $save = 0;
    chomp($dline);
    @col = split(/\t/,$dline);
    $accnum = $col[0];
    $seclist = $col[7];
    if(defined($wantid{$accnum})){
	$save=1;
	++$gotid{$accnum};
    }
    elsif(defined($seclist) && $seclist ne ""){
	@sec=split(/[; ]/,$seclist);
	foreach $sec (@sec) {
	    if(defined($wantid{$sec})){
		$save=1;
		++$gotid{$sec};
		++$gotidsec{$sec};
	    }
	}
    }
    if($save) {
	print "$dline\n";
	++$saveline;
    }
}
close DIC;

print STDERR "Reading /data/scratch/git-master/dictionaries/uniprot-dictionary1.tsv\n";
open (DIC, "/data/scratch/git-master/dictionaries/uniprot-dictionary1.tsv") || die "Cannot open dictionary";
$dline = <DIC>;

$line=1;
$savelineb = 0;
while($dline = <DIC>){
    $line++;
    $save = 0;
    chomp($dline);
    @col = split(/\t/,$dline);
    $accnum = $col[0];
    $seclist = $col[7];
    if(defined($wantid{$accnum}) && !defined($gotid{$accnum})){
	$save=1;
	++$gotid{$accnum};
    }
    elsif(defined($seclist) && $seclist ne ""){
	@sec=split(/[; ]/,$seclist);
	foreach $sec (@sec) {
	    if(defined($wantid{$sec}) && !defined($gotid{$sec})){
		$save=1;
		++$gotid{$sec};
		++$gotidsec{$sec};
	    }
	}
    }
    if($save) {
	print "$dline\n";
	print STDERR "$dline\n";
	++$savelineb;
    }
}
close DIC;

print STDERR "Wanted $wanted found $saveline old found $savelineb\n";

$gotsec=0;
foreach $id (keys(%wantid)){
    if(!defined($gotid{$id})) {
	print STDERR "Missing $id\n";
	$testdel{$id}=1;
    }
    elsif(defined($gotidsec{$id})){$gotsec++}
}
print STDERR "Found $gotsec secondary ids\n";

open(DELSP, "delac_sp.txt") || die "Cannot read deleted IDs for Swissprot";
$head = 1;
while(<DELSP>) {
    if(!$head && /^(\S+)/){
	$id = $1;
	if(defined($testdel{$id})){
	    print "$id\t$id\t$id deleted in SwissProt\t$id deleted in SwissProt\tHomo sapiens\t\t\t\n";
	    print STDERR "$id delac_sp\n";
	}
    }
    if(/^_*$/) {
	$head=0;
    }
}
close DELSP;
open(DELSP, "delac_tr.txt") || die "Cannot read deleted IDs for SpTrEMBL";
$head = 1;
while(<DELSP>) {
    if(!$head && /^(\S+)/){
	$id = $1;
	if(defined($testdel{$id})){
	    print "$id\t$id\t$id deleted in SpTrEMBL\t$id deleted in SpTrEMBL\tHomo sapiens\t\t\t\n";
	    print STDERR "$id delac_tr\n";
	}
    }
    if(/^_*$/) {
	$head=0;
    }
}
close DELSP;
